summaryrefslogtreecommitdiff
path: root/test/unit/parser/parser_black.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/unit/parser/parser_black.cpp')
-rw-r--r--test/unit/parser/parser_black.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/unit/parser/parser_black.cpp b/test/unit/parser/parser_black.cpp
index 87556d53d..827d7dd84 100644
--- a/test/unit/parser/parser_black.cpp
+++ b/test/unit/parser/parser_black.cpp
@@ -9,10 +9,10 @@
** All rights reserved. See the file COPYING in the top-level source
** directory for licensing information.\endverbatim
**
** \brief Black box testing of CVC4::parser::Parser for CVC and SMT-LIBv2
** inputs.
**
** Black box testing of CVC4::parser::Parser for CVC and SMT-LIbv2 inputs.
**/
#include <sstream>
@@ -29,7 +29,7 @@
#include "smt/command.h"
#include "test.h"
-namespace CVC4 {
+namespace CVC5 {
using namespace parser;
using namespace language::input;
@@ -48,7 +48,7 @@ class TestParserBlackParser : public TestInternal
TestInternal::SetUp();
d_options.set(options::parseOnly, true);
d_symman.reset(nullptr);
- d_solver.reset(new CVC4::api::Solver(&d_options));
+ d_solver.reset(new CVC5::api::Solver(&d_options));
}
void TearDown() override
@@ -186,7 +186,7 @@ class TestParserBlackParser : public TestInternal
Options d_options;
InputLanguage d_lang;
- std::unique_ptr<CVC4::api::Solver> d_solver;
+ std::unique_ptr<CVC5::api::Solver> d_solver;
std::unique_ptr<SymbolManager> d_symman;
};
@@ -392,4 +392,4 @@ TEST_F(TestParserBlackSmt2Parser, bad_exprs)
#endif
}
} // namespace test
-} // namespace CVC4
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback
@@ -9,10 +9,10 @@
** directory for licensing information.\endverbatim
**
- ** \brief Black box testing of CVC4::parser::Parser for CVC and SMT-LIBv2
+ ** \brief Black box testing of CVC5::parser::Parser for CVC and SMT-LIBv2
** inputs.
**
@@ -9,10 +9,10 @@
** inputs.
**
- ** Black box testing of CVC4::parser::Parser for CVC and SMT-LIbv2 inputs.
+ ** Black box testing of CVC5::parser::Parser for CVC and SMT-LIbv2 inputs.
**/
#include <sstream>